/*
 * Vifir - An electronic flight bag wannabe utility for aircraft pilots
 * Copyright (C) 2009 David Ludlow
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * dave@adsllc.com, PO Box 13070, Toledo, OH 43623
 */

#include <glibmm/i18n.h>
#include <gtkmm/messagedialog.h>
#include <gtkmm/main.h>
#include "OverwriteFileDialog.h"
#include "Util.h"

OverwriteFileDialog::OverwriteFileDialog(std::string *GladeFilename)
{
	try
	{
		refXml = Gnome::Glade::Xml::create(*GladeFilename, "OverwriteFileDialog");
	}
	catch (const Gnome::Glade::XmlError& ex)
	{
		Gtk::MessageDialog *message = new Gtk::MessageDialog(_("Error reading data file: ")+*GladeFilename+"\n"+_("Program cannot continue."),
			false,Gtk::MESSAGE_ERROR,Gtk::BUTTONS_CANCEL,true);
		message->run();
		Gtk::Main::quit();
		return;
	}

	refXml->get_widget("OverwriteFileDialog",GtkDialog);
	refXml->get_widget("PathLabel",PathLabel);

	GtkDialog->set_deletable(false);
	Reset();
}

OverwriteFileDialog::~OverwriteFileDialog()
{
	delete GtkDialog;
}

enum OverwriteFileDialog::Response_enum OverwriteFileDialog::Run(std::string Path) {
	enum Response_Internal_enum InternalResponse;
	enum Response_enum Response=RESPONSE_CANCEL;

	if (Do==DO_KEEPALL)
		return RESPONSE_KEEP;
	if (Do==DO_OVERWRITEALL)
		return RESPONSE_OVERWRITE;

	PathLabel->set_text(Path.c_str());
	GtkDialog->show_all();
	InternalResponse=(enum Response_Internal_enum)GtkDialog->run();

	switch (InternalResponse) {
		case RESPONSE_INTERNAL_CANCEL:
			Response=RESPONSE_CANCEL;
			break;
		case RESPONSE_INTERNAL_KEEP:
			Response=RESPONSE_KEEP;
			break;
		case RESPONSE_INTERNAL_OVERWRITE:
			Response=RESPONSE_OVERWRITE;
			break;
		case RESPONSE_INTERNAL_KEEPALL:
			Do=DO_KEEPALL;
			Response=RESPONSE_KEEP;
			break;
		case RESPONSE_INTERNAL_OVERWRITEALL:
			Do=DO_OVERWRITEALL;
			Response=RESPONSE_OVERWRITE;
			break;
	}

	GtkDialog->hide();
	Util::ScheduleMainLoop();	/* Hide the dialog before continuing */

	return Response;
}

void OverwriteFileDialog::Reset() {
	Do=DO_ASK;
}
